pygerber.renderer package
=========================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   pygerber.renderer.aperture

Submodules
----------

.. toctree::
   :maxdepth: 4

   pygerber.renderer.aperture_manager
   pygerber.renderer.apertureset
   pygerber.renderer.arc_util_mixin
   pygerber.renderer.spec

Module contents
---------------

.. automodule:: pygerber.renderer
   :members:
   :undoc-members:
   :show-inheritance:
